@@ -61,8 +61,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 67169 2011-03-11 03:42:56Z CJP $"
-__revision__ = "$Revision: 67169 $"
+__svnid__ = "$Id: outbuff.py 67552 2011-04-20 20:28:47Z CJP $"
+__revision__ = "$Revision: 67552 $"
 
 __all__ = ["OutputBuffer", "OutputBufferEvent", "ProcessBufferMixin",
            "ProcessThreadBase", "ProcessThread", "TaskThread", 
@@ -252,7 +252,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self.SetSelBackground(True, highlight)
         self.__SetupStyles()
 
-    def __FlushBuffer(self):
+    def FlushBuffer(self):
         """Flush the update buffer
         @postcondition: The update buffer is empty
 
@@ -321,6 +321,8 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
 
         """
         self._updating.acquire()
+        if not (type(value) is types.UnicodeType):
+            value = value.decode(sys.getfilesystemencoding())
         self._updates.append(value)
         self._updating.release()
 
@@ -451,9 +453,8 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
                return quickly to avoid blocking the ui.
 
         """
-        ind = len(self._updates)
-        if ind:
-            self.__FlushBuffer()
+        if len(self._updates):
+            self.FlushBuffer()
         elif evt is not None:
             self.DoUpdatesEmpty()
         else:
@@ -746,9 +747,12 @@ class ProcessThreadBase(threading.Thread):
         except UnicodeDecodeError:
             result = os.linesep
 
-        evt = OutputBufferEvent(edEVT_UPDATE_TEXT, self._parent.GetId(), result)
-        wx.PostEvent(self._parent, evt)
-        return True
+        if self.Parent:
+            evt = OutputBufferEvent(edEVT_UPDATE_TEXT, self.Parent.GetId(), result)
+            wx.PostEvent(self.Parent, evt)
+            return True
+        else:
+            return False # Parent is dead no need to keep running
 
     def __KillPid(self, pid):
         """Kill a process by process id, causing the run loop to exit
@@ -822,15 +826,17 @@ class ProcessThreadBase(threading.Thread):
         except OSError, msg:
             # NOTE: throws WindowsError on Windows which is a subclass of
             #       OSError, so it will still get caught here.
-            err =  OutputBufferEvent(edEVT_PROCESS_ERROR,
-                                     self.Parent.GetId(),
-                                     OPB_ERROR_INVALID_COMMAND)
-            err.SetErrorMessage(msg)
+            if self.Parent:
+                err =  OutputBufferEvent(edEVT_PROCESS_ERROR,
+                                         self.Parent.GetId(),
+                                         OPB_ERROR_INVALID_COMMAND)
+                err.SetErrorMessage(msg)
 
-        evt = OutputBufferEvent(edEVT_PROCESS_START,
-                                self.Parent.GetId(),
-                                self.LastCommand)
-        wx.PostEvent(self.Parent, evt)
+        if self.Parent:
+            evt = OutputBufferEvent(edEVT_PROCESS_START,
+                                    self.Parent.GetId(),
+                                    self.LastCommand)
+            wx.PostEvent(self.Parent, evt)
 
         # Read from stdout while there is output from process
         while not err and True:
@@ -853,7 +859,8 @@ class ProcessThreadBase(threading.Thread):
 
         # Notify of error in running the process
         if err is not None:
-            wx.PostEvent(self.Parent, err)
+            if self.Parent:
+                wx.PostEvent(self.Parent, err)
             result = -1
         else:
             try:
@@ -863,8 +870,9 @@ class ProcessThreadBase(threading.Thread):
 
         # Notify that process has exited
         # Pack the exit code as the events value
-        evt = OutputBufferEvent(edEVT_PROCESS_EXIT, self.Parent.GetId(), result)
-        wx.PostEvent(self.Parent, evt)
+        if self.Parent:
+            evt = OutputBufferEvent(edEVT_PROCESS_EXIT, self.Parent.GetId(), result)
+            wx.PostEvent(self.Parent, evt)
 
 class ProcessThread(ProcessThreadBase):
     """Run a subprocess in a separate thread. Thread posts events back
@@ -936,7 +944,7 @@ class ProcessThread(ProcessThreadBase):
         # TODO: if a file path to the exe has any spaces in it on Windows
         #       and use_shell is True then the command will fail. Must force
         #       to False under this condition.
-        use_shell = self._use_shell and not subprocess.mswindows
+        use_shell = self._use_shell
         # TODO: See about supporting use_shell on Windows it causes lots of
         #       issues with gui apps and killing processes when it is True.
         if use_shell and subprocess.mswindows:
