@@ -14,8 +14,8 @@ Text editor buffer view control for the main notebook
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_editv.py 66482 2010-12-28 21:57:50Z CJP $"
-__revision__ = "$Revision: 66482 $"
+__svnid__ = "$Id: ed_editv.py 67542 2011-04-19 00:26:29Z CJP $"
+__revision__ = "$Revision: 67542 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -31,6 +31,7 @@ import ed_tab
 from doctools import DocPositionMgr
 from profiler import Profile_Get
 from util import Log, SetClipboardText
+import syntax.synglob as synglob
 from ebmlib import GetFileModTime, ContextMenuManager, GetFileName
 
 # External libs
@@ -74,6 +75,7 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         ed_tab.EdTabBase.__init__(self)
 
         # Attributes
+        self._ro_img = False
         self._ignore_del = False
         self._has_dlg = False
         self._lprio = 0     # Idle event priority counter
@@ -151,6 +153,7 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
                 self._caret_w = cwidth
             self.SetCaretWidth(0) # Hide the caret when not active
             self._focused = False
+            self.CallTipCancel()
 
         # Check for changes to on disk file
         if not self._has_dlg and Profile_Get('CHECKMOD'):
@@ -169,18 +172,9 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
                     wx.CallAfter(self.AskToReload, cfile)
 
         # Check for changes to permissions
-        readonly = self._nb.ImageIsReadOnly(self.GetTabIndex())
-        if self.File.IsReadOnly() != readonly:
-            if readonly:
-                # File is no longer read only
-                self._nb.SetPageImage(self.GetTabIndex(),
-                                      str(self.GetLangId()))
-            else:
-                # File has changed to be readonly
-                self._nb.SetPageImage(self.GetTabIndex(),
-                                      ed_glob.ID_READONLY)
+        if self.File.IsReadOnly() != self._ro_img:
+            self._nb.SetPageBitmap(self.GetTabIndex(), self.GetTabImage())
             self._nb.Refresh()
-
         else:
             pass
 
@@ -191,8 +185,12 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
             # Do spell checking
             # TODO: Add generic subscriber hook and move spell checking and
             #       and other low priority idle handling there
-            if self._spell_data['enabled']:
-                self._spell.processCurrentlyVisibleBlock()
+            if self.IsShown():
+                if self._spell_data['enabled']:
+                    self._spell.processCurrentlyVisibleBlock()
+            else:
+                # Ensure calltips are not shown when this is a background tab.
+                self.CallTipCancel()
 
     @modalcheck
     def DoReloadFile(self):
@@ -231,6 +229,22 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         """
         return u"EditraTextCtrl"
 
+    def GetTabImage(self):
+        """Get the Bitmap to use for the tab
+        @return: wx.Bitmap (16x16)
+
+        """
+        if self.GetDocument().ReadOnly:
+            self._ro_img = True
+            bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_READONLY), wx.ART_MENU)
+        else:
+            self._ro_img = False
+            lang_id = str(self.GetLangId())
+            bmp = wx.ArtProvider.GetBitmap(lang_id, wx.ART_MENU)
+            if bmp.IsNull():
+                bmp = wx.ArtProvider.GetBitmap(str(synglob.ID_LANG_TXT), wx.ART_MENU)
+        return bmp
+
     def GetTabMenu(self):
         """Get the tab menu
         @return: wx.Menu
