@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 67126 2011-03-04 23:44:13Z CJP $"
-__revision__ = "$Revision: 67126 $"
+__svnid__ = "$Id: ed_main.py 67568 2011-04-21 23:19:00Z CJP $"
+__revision__ = "$Revision: 67568 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -89,7 +89,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                             CONFIG['CACHE_DIR'])
 
         # Setup app icon and title
-        self.SetTitle()
         util.SetWindowIcon(self)
 
         # Attributes
@@ -444,7 +443,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
             dlg = wx.FileDialog(self, _("Editra: Open"), fdir, "",
                                 ''.join(syntax.GenFileFilters()),
-                                wx.OPEN | wx.MULTIPLE)
+                                wx.OPEN | wx.MULTIPLE | wx.CHANGE_DIR)
             dlg.SetFilterIndex(_PGET('FFILTER', 'int', 0))
 
             if ebmlib.LockCall(self._mlock, dlg.ShowModal) == wx.ID_OK:
@@ -885,13 +884,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         # Save session files
-        session = _PGET('LAST_SESSION')
-        if not isinstance(session, basestring) or not len(session):
-            session = os.path.join(CONFIG['SESSION_DIR'], u"__default.session")
-        _PSET('LAST_SESSION', session)
-        result = self.nb.SaveSessionFile(session)
-        if result is not None:
-            pass # TODO: report error?
+        self.nb.SaveCurrentSession()
 
         # Cleanup Controls
         self._exiting = True
@@ -1529,10 +1522,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type title: string
 
         """
-        name = "%s v%s" % (PROG_NAME, VERSION)
+        name = u"%s v%s" % (PROG_NAME, VERSION)
         if len(title):
-            name = " - " + name
-        wx.Frame.SetTitle(self, title + name)
+            name = u" - " + name
+        super(MainWindow, self).SetTitle(title + name)
 
     def SetupToolBar(self):
         """Setup or reinitialize the windows ToolBar"""
