@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 67027 2011-02-25 21:04:49Z CJP $"
-__revision__ = "$Revision: 67027 $"
+__svnid__ = "$Id: ed_pages.py 67571 2011-04-22 01:10:57Z CJP $"
+__revision__ = "$Revision: 67571 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -26,7 +26,7 @@ import wx
 
 # Editra Libraries
 import ed_glob
-from profiler import Profile_Get
+from profiler import Profile_Get, Profile_Set
 import ed_editv
 import syntax.synglob as synglob
 import syntax.syntax as syntax
@@ -38,20 +38,22 @@ import ed_mdlg
 import ebmlib
 import eclib
 from extern import aui
+import ed_book
 
 #--------------------------------------------------------------------------#
 # Globals
 ID_IDLE_TIMER = wx.NewId()
 SIMULATED_EVT_ID = -1
 _ = wx.GetTranslation
+
 #--------------------------------------------------------------------------#
 
-class EdPages(aui.AuiNotebook):
+class EdPages(ed_book.EdBaseBook):
     """Editra's editor buffer notebook
     @todo: allow for tab styles to be configurable (maybe)
 
     """
-    def __init__(self, parent, id_num):
+    def __init__(self, parent):
         """Initialize a notebook with a blank text control in it
         @param parent: parent window of the notebook
         @param id_num: this notebooks id
@@ -63,11 +65,8 @@ class EdPages(aui.AuiNotebook):
                 aui.AUI_NB_USE_IMAGES_DROPDOWN | \
                 aui.AUI_NB_TAB_EXTERNAL_MOVE | \
                 aui.AUI_NB_TAB_FIXED_WIDTH | \
-                aui.AUI_NB_ORDER_BY_ACCESS | \
-                aui.AUI_NB_NO_TAB_FOCUS
-        if wx.Platform == '__WXMAC__':
-            style |= aui.AUI_NB_CLOSE_ON_TAB_LEFT
-        super(EdPages, self).__init__(parent, id_num, agwStyle=style)
+                aui.AUI_NB_ORDER_BY_ACCESS
+        super(EdPages, self).__init__(parent, style=style)
 
         # Notebook attributes
         self.LOG = wx.GetApp().GetLog()
@@ -82,7 +81,6 @@ class EdPages(aui.AuiNotebook):
         self.mdown = -1
         self.control = None
         self.frame = self.GetTopLevelParent() # MainWindow
-        self._index = dict()          # image list index
         self._ses_load = False
         self._menu = ebmlib.ContextMenuManager()
 
@@ -94,14 +92,6 @@ class EdPages(aui.AuiNotebook):
         else:
             util.Log("[ed_pages][warn] Bad bitmap: %s" % ed_icon)
 
-        # Setup the ImageList and the default image
-        imgl = wx.ImageList(16, 16)
-        txtbmp = wx.ArtProvider.GetBitmap(str(synglob.ID_LANG_TXT), wx.ART_MENU)
-        self._index[synglob.ID_LANG_TXT] = imgl.Add(txtbmp)
-        robmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_READONLY), wx.ART_MENU)
-        self._index[ed_glob.ID_READONLY] = imgl.Add(robmp)
-        self.SetImageList(imgl)
-
         # Set custom options
         self.SetSashDClickUnsplit(True)
         self.SetMinMaxTabWidth(125, 135)
@@ -149,7 +139,7 @@ class EdPages(aui.AuiNotebook):
             ed_msg.UnRegisterCallback(self.OnDocPointerRequest)
 
     #---- Function Definitions ----#
-    
+
     def _HandleEncodingError(self, control):
         """Handle trying to reload the file the file with a different encoding
         Until it suceeds or gives up.
@@ -238,16 +228,22 @@ class EdPages(aui.AuiNotebook):
 
     def AddPage(self, page, text=u'', select=True, imgId=-1):
         """Add a page to the notebook"""
+        bNewPage = False
         if not len(text):
             self.pg_num += 1
             if self.pg_num != 0:
                 text = _("untitled %d") % self.pg_num
             else:
                 text = _("untitled")
+            bNewPage = True
         page.SetTabLabel(text)
-        super(EdPages, self).AddPage(page, text, select)
-        self.SetPageImage(self.GetPageCount()-1, str(page.GetLangId()))
+        bmp = wx.NullBitmap
+        if Profile_Get('TABICONS'):
+            bmp = page.GetTabImage()
+        super(EdPages, self).AddPage(page, text, select, bitmap=bmp)
         self.UpdateIndexes()
+        if not self._ses_load and not bNewPage:
+            self.SaveCurrentSession()
 
     def DocDuplicated(self, path):
         """Check for if the given path is open elsewhere and duplicate the
@@ -315,7 +311,7 @@ class EdPages(aui.AuiNotebook):
                 (ed_glob.ID_NEXT_POS, self.OnUpdateNaviUI),
                 (ed_glob.ID_PRE_POS, self.OnUpdateNaviUI)]
 
-    def InsertPage(self, index, page, text, select=False, 
+    def InsertPage(self, index, page, text, select=False,
                    bitmap=wx.NullBitmap, disabled_bitmap=wx.NullBitmap,
                    control=None):
         """Insert a page into the notebook"""
@@ -323,6 +319,16 @@ class EdPages(aui.AuiNotebook):
                                         bitmap, disabled_bitmap, control)
         self.UpdateIndexes()
 
+    def SaveCurrentSession(self):
+        """Save the current session"""
+        session = Profile_Get('LAST_SESSION')
+        # Compatibility with older session data
+        if not isinstance(session, basestring) or not len(session):
+            session = os.path.join(ed_glob.CONFIG['SESSION_DIR'], 
+                                   u"__default.session")
+            Profile_Set('LAST_SESSION', session)
+        self.SaveSessionFile(session)
+
     def SaveSessionFile(self, session):
         """Save the current open files to the given session file
         @param session: path to session file
@@ -338,6 +344,8 @@ class EdPages(aui.AuiNotebook):
         try:
             sdata = dict(win1=self.GetFileNames())
             cPickle.dump(sdata, f_handle)
+        except Exception, msg:
+            self.LOG("[ed_pages][err] Failed to SaveSessionFile: %s" % msg)
         finally:
             f_handle.close()
 
@@ -370,7 +378,7 @@ class EdPages(aui.AuiNotebook):
                 flist = cPickle.load(f_handle)
                 # TODO: Extend in future to support loading sessions
                 #       for multiple windows.
-                flist = flist.get('win1', list()) 
+                flist = flist.get('win1', list())
                 for item in flist:
                     if type(item) not in (unicode, str):
                         raise TypeError("Invalid item in unpickled sequence")
@@ -400,7 +408,7 @@ class EdPages(aui.AuiNotebook):
                               os.path.basename(loadfn))
             else:
                 missingfns.append(loadfn)
-                
+
         if missingfns:
             rmsg = (_("Missing session files"),
                     _("Some files in saved session could not be found on disk:\n")+
@@ -424,20 +432,18 @@ class EdPages(aui.AuiNotebook):
         frame = self.GetTopLevelParent()
         frame.Freeze()
         try:
-            self.control = ed_editv.EdEditorView(self, wx.ID_ANY)
-            self.LOG("[ed_pages][evt] New Page Created ID: %d" % self.control.GetId())
-            self.control.Hide()
+            self.control = ed_editv.EdEditorView(self)
+            self.LOG("[ed_pages][evt] New Page Created")
             self.AddPage(self.control)
-            self.control.Show()
         finally:
             frame.Thaw()
 
         # Set the control up the the preferred default lexer
-        dlexer = Profile_Get('DEFAULT_LEX', 'str', 'Plain Text')
+        dlexer = Profile_Get('DEFAULT_LEX', 'str', synglob.LANG_TXT)
         ext_reg = syntax.ExtensionRegister()
         ext_lst = ext_reg.get(dlexer, ['txt', ])
         self.control.FindLexer(ext_lst[0])
-        self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
+        self.SetPageBitmap(self.GetSelection(), self.control.GetTabImage())
 
         # Set the modified callback notifier
         doc = self.control.GetDocument()
@@ -660,12 +666,10 @@ class EdPages(aui.AuiNotebook):
         else:
             self.SetPageText(self.GetSelection(), filename)
 
-        self.frame.SetTitle(nbuff.GetTitleString())
         self.LOG("[ed_pages][evt] Opened Page: %s" % filename)
 
         # Set tab image
-        # TODO: Handle read only images
-        self.SetPageImage(self.GetSelection(), str(nbuff.GetLangId()))
+        self.SetPageBitmap(self.GetSelection(), nbuff.GetTabImage())
 
         # Refocus on selected page
         self.control = nbuff
@@ -702,18 +706,13 @@ class EdPages(aui.AuiNotebook):
         self.control.Show()
         self.AddPage(self.control, filename)
 
-        self.frame.SetTitle(self.control.GetTitleString())
         self.frame.AddFileToHistory(path)
         self.SetPageText(self.GetSelection(), filename)
         self.LOG("[ed_pages][evt] Opened Page: %s" % filename)
 
         # Set tab image
         cpage = self.GetSelection()
-        if fileobj.ReadOnly:
-            super(EdPages, self).SetPageImage(cpage,
-                                              self._index[ed_glob.ID_READONLY])
-        else:
-            self.SetPageImage(cpage, str(self.control.GetLangId()))
+        self.SetPageBitmap(cpage, self.control.GetTabImage())
 
         self.GetTopLevelParent().Thaw()
 
@@ -831,17 +830,12 @@ class EdPages(aui.AuiNotebook):
         if new_pg:
             self.AddPage(self.control, filename)
 
-        self.frame.SetTitle(self.control.GetTitleString())
         self.frame.AddFileToHistory(path2file)
         self.SetPageText(self.GetSelection(), filename)
 
         # Set tab image
         cpage = self.GetSelection()
-        if doc.ReadOnly:
-            super(EdPages, self).SetPageImage(cpage,
-                                              self._index[ed_glob.ID_READONLY])
-        else:
-            self.SetPageImage(cpage, str(self.control.GetLangId()))
+        self.SetPageBitmap(cpage, self.control.GetTabImage())
 
         if Profile_Get('WARN_EOL', default=True) and not doc.IsRawBytes():
             self.control.CheckEOL()
@@ -1112,7 +1106,7 @@ class EdPages(aui.AuiNotebook):
         cpage = evt.GetSelection()
         self.ChangePage(cpage, old=evt.GetOldSelection())
         self.LOG("[ed_pages][evt] Page Changed to %d" % cpage)
-        
+
         # Call the tab specific selection handler
         page = self.GetCurrentPage()
         if page:
@@ -1149,7 +1143,7 @@ class EdPages(aui.AuiNotebook):
         frame = self.GetTopLevelParent()
         frame.Freeze()
         try:
-            cpage = evt.GetSelection() #self.GetSelection()
+            cpage = evt.GetSelection()
             evt.Skip()
             self.LOG("[ed_pages][evt] Closed Page: #%d" % cpage)
             self.UpdateIndexes()
@@ -1160,6 +1154,8 @@ class EdPages(aui.AuiNotebook):
             if not self.GetPageCount() and \
                hasattr(frame, 'IsExiting') and not frame.IsExiting():
                 self.NewPage()
+            elif not self.frame.IsExiting():
+                self.SaveCurrentSession()
         finally:
             frame.Thaw()
 
@@ -1199,7 +1195,7 @@ class EdPages(aui.AuiNotebook):
 
     def CloseAllPages(self):
         """Closes all open pages"""
-        for page in xrange(self.GetPageCount()):
+        for page in range(self.GetPageCount()):
             if not self.ClosePage():
                 break
 
@@ -1242,54 +1238,19 @@ class EdPages(aui.AuiNotebook):
             return page.CanCloseTab()
         return False
 
-    def SetPageImage(self, pg_num, lang_id):
-        """Sets the page image by querying the ArtProvider based
-        on the language id associated with the type of open document.
-        Any unknown filetypes are associated with the plaintext page
-        image.
-        @param pg_num: page index to set image for
-        @param lang_id: language id of file type to get mime image for
-
-        """
-        # Only set icons when enabled in preferences
-        if not Profile_Get('TABICONS'):
-            return
-
-        imglst = self.GetImageList()
-        if lang_id not in self._index:
-            bmp = wx.ArtProvider.GetBitmap(lang_id, wx.ART_MENU)
-            if bmp.IsNull():
-                self._index.setdefault(lang_id, \
-                                       self._index[synglob.ID_LANG_TXT])
-            else:
-                self._index[lang_id] = imglst.Add(wx.ArtProvider.\
-                                              GetBitmap(lang_id, wx.ART_MENU))
-        super(EdPages, self).SetPageImage(pg_num, self._index[lang_id])
-
     def UpdateAllImages(self):
         """Reload and Reset all images in the notebook pages and
         the corresponding imagelist to match those of the current theme
         @postcondition: all images in control are updated
 
         """
-        # If icons preference has been disabled then clear all icons
-        if not Profile_Get('TABICONS'):
-            for page in range(self.GetPageCount()):
-                super(EdPages, self).SetPageImage(page, -1)
-        else:
-            # Reload the image list with new icons from the ArtProvider
-            imglst = self.GetImageList()
-            for lang, index in self._index.iteritems():
-                bmp = wx.ArtProvider.GetBitmap(str(lang), wx.ART_MENU)
-                if bmp.IsNull():
-                    self._index.setdefault(lang, \
-                                           self._index[synglob.ID_LANG_TXT])
-                else:
-                    imglst.Replace(index, bmp)
-
-            for page in xrange(self.GetPageCount()):
-                self.SetPageImage(page, str(self.GetPage(page).GetLangId()))
-
+        bUseIcons = Profile_Get('TABICONS')
+        for page in range(self.GetPageCount()):
+            if bUseIcons:
+                tab = self.GetPage(page)
+                self.SetPageBitmap(page, tab.GetTabImage())
+            else:
+                self.SetPageBitmap(page, wx.NullBitmap)
         self.Refresh()
 
     def UpdateIndexes(self):
@@ -1303,7 +1264,8 @@ class EdPages(aui.AuiNotebook):
         @postcondition: page image is updated to reflect any changes in ctrl
 
         """
-        self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
+        tab = self.GetCurrentPage()
+        self.SetPageBitmap(self.GetSelection(), tab.GetTabImage())
 
     def OnUpdatePageText(self, evt):
         """Update the title text of the current page
