@@ -14,26 +14,26 @@ Shelf plugin and control implementation
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_shelf.py 67235 2011-03-18 17:44:07Z CJP $"
-__revision__ = "$Revision: 67235 $"
+__svnid__ = "$Id: ed_shelf.py 67547 2011-04-19 15:59:41Z CJP $"
+__revision__ = "$Revision: 67547 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
 import re
 import wx
 
-# Editra Libraries
+# Editra Imports
 import ed_menu
 import ed_glob
 from profiler import Profile_Get
 import ed_msg
 import plugin
 import iface
-import extern.aui as aui
+from extern import aui
+import ed_book
 
 #--------------------------------------------------------------------------#
 # Globals
-
 PGNUM_PAT = re.compile(' - [0-9]+')
 _ = wx.GetTranslation
 
@@ -135,7 +135,7 @@ class Shelf(plugin.Plugin):
 
 #--------------------------------------------------------------------------#
 
-class EdShelfBook(aui.AuiNotebook):
+class EdShelfBook(ed_book.EdBaseBook):
     """Shelf notebook control"""
     def __init__(self, parent):
         style = aui.AUI_NB_BOTTOM | \
@@ -143,21 +143,15 @@ class EdShelfBook(aui.AuiNotebook):
                 aui.AUI_NB_SCROLL_BUTTONS | \
                 aui.AUI_NB_CLOSE_ON_ACTIVE_TAB | \
                 aui.AUI_NB_TAB_MOVE | \
-                aui.AUI_NB_DRAW_DND_TAB | \
-                aui.AUI_NB_NO_TAB_FOCUS
-        if wx.Platform == '__WXMAC__':
-            style |= aui.AUI_NB_CLOSE_ON_TAB_LEFT
-        super(EdShelfBook, self).__init__(parent, agwStyle=style)
+                aui.AUI_NB_DRAW_DND_TAB
+        super(EdShelfBook, self).__init__(parent, style=style)
 
         # Attributes
         self._parent = parent
         self._open = dict()
-        self._imgidx = dict()
-        self._imglst = wx.ImageList(16, 16)
         self._name2idx = dict() # For settings maintenance
 
         # Setup
-        self.SetImageList(self._imglst)
         self.SetSashDClickUnsplit(True)
 
         # Event Handlers
@@ -165,27 +159,23 @@ class EdShelfBook(aui.AuiNotebook):
 
         # Message handlers
         ed_msg.Subscribe(self.OnUpdateTabs, ed_msg.EDMSG_THEME_NOTEBOOK)
+        ed_msg.Subscribe(self.OnUpdateTabs, ed_msg.EDMSG_THEME_CHANGED)
 
     def OnDestroy(self, evt):
         if evt.GetId() == self.GetId():
             ed_msg.Unsubscribe(self.OnUpdateTabs)
         evt.Skip()
 
-    @property
-    def ImgIdx(self):
-        return self._imgidx
+    BitmapCallbacks = property(lambda self: self._name2idx)
 
-    @property
-    def ImageList(self):
-        return self._imglst
-
-    def AddItem(self, item, name, imgid=-1):
+    def AddItem(self, item, name, bmp=wx.NullBitmap):
         """Add an item to the shelf's notebook. This is useful for interacting
         with the Shelf from outside its interface. It may be necessary to
         call L{EnsureShelfVisible} before or after adding an item if you wish
         the shelf to be shown when the item is added.
         @param item: A panel like instance to add to the shelf's notebook
         @param name: Items name used for page text in notebook
+        @keyword bmp: Tab bitmap to display
 
         """
         self.AddPage(item, 
@@ -193,9 +183,8 @@ class EdShelfBook(aui.AuiNotebook):
                      select=True)
 
         # Set the tab icon
-        self._name2idx[repr(item.__class__)] = imgid
-        if imgid >= 0 and Profile_Get('TABICONS', default=True):
-            self.SetPageImage(self.GetPageCount()-1, imgid)
+        if Profile_Get('TABICONS', default=True):
+            self.SetPageBitmap(self.GetPageCount()-1, bmp)
         self._open[name] = self._open.get(name, 0) + 1
 
     @mainwinonly
@@ -277,13 +266,13 @@ class EdShelfBook(aui.AuiNotebook):
         """Update all tab images depending upon current settings"""
         if not Profile_Get('TABICONS', default=True):
             for page in range(self.GetPageCount()):
-                self.SetPageImage(page, -1)
+                self.SetPageBitmap(page, wx.NullBitmap)
         else:
             # Show the icons
             for pnum in range(self.GetPageCount()):
                 page = self.GetPage(pnum)
-                imgid = self._name2idx.get(repr(page.__class__), -1)
-                self.SetPageImage(pnum, imgid)
+                bmp = self.BitmapCallbacks.get(repr(page.__class__), lambda:wx.NullBitmap)()
+                self.SetPageBitmap(pnum, bmp)
 
 #--------------------------------------------------------------------------#
 
@@ -309,9 +298,9 @@ class EdShelfDelegate(object):
     def observers(self):
         return self._pin.observers
 
-    def AddItem(self, item, name, imgid=-1):
+    def AddItem(self, item, name, bmp=wx.NullBitmap):
         """Add an item to the shelf"""
-        self._shelf.AddItem(item, name, imgid)
+        self._shelf.AddItem(item, name, bmp)
 
     def CanStockItem(self, item_name):
         """See if a named item can be stocked or not, meaning if it
@@ -419,7 +408,7 @@ class EdShelfDelegate(object):
             combo += 1
             shortcut = u""
             if combo < 10:
-                shortcut = u"\tCtrl+Alt+" + str(combo)
+                shortcut = u"\tCtrl+Alt+" + unicode(combo)
             item[1].SetText(item[1].GetText() + shortcut)
             menu.AppendItem(item[1])
         return menu
@@ -494,18 +483,14 @@ class EdShelfDelegate(object):
             return
         else:
             self.EnsureShelfVisible()
-            item_id = item.GetId()
-            index = -1
+            window = item.CreateItem(self._shelf)
+            bmp = wx.NullBitmap
             if hasattr(item, 'GetBitmap'):
-                if item_id in self._shelf.ImgIdx:
-                    index = self._shelf.ImgIdx[item_id]
-                else:
-                    bmp = item.GetBitmap()
-                    if bmp.IsOk():
-                        index = self._shelf.ImageList.Add(bmp)
-                        self._shelf.ImgIdx[item_id] = index
-
-            self.AddItem(item.CreateItem(self._shelf), name, index)
+                self._shelf.BitmapCallbacks[repr(window.__class__)] = item.GetBitmap
+                bmp = item.GetBitmap()
+            else:
+                self._shelf.BitmapCallbacks[repr(window.__class__)] = lambda:wx.NullBitmap
+            self.AddItem(window, name, bmp)
 
     def RaiseItem(self, item_name):
         """Set the selection in the notebook to be the that of the first
