@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 67115 2011-03-03 04:28:25Z CJP $"
-__revision__ = "$Revision: 67115 $"
+__svnid__ = "$Id: ed_stc.py 67517 2011-04-16 20:29:35Z CJP $"
+__revision__ = "$Revision: 67517 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -240,7 +240,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         @keyword line: if < 0 bookmark will be added to current line
 
         """
-        rval = super(EditraStc, self).AddBookmark(line)
+        rval = self.AddMarker(ed_marker.Bookmark(), line)
         mdata = dict(stc=self, added=True, line=line, handle=rval)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
         return rval
@@ -251,7 +251,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         @param line: int
 
         """
-        super(EditraStc, self).RemoveBookmark(line)
+        self.RemoveMarker(ed_marker.Bookmark(), line)
         mdata = dict(stc=self, added=False, line=line)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
 
@@ -260,7 +260,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
         Sends notifications for bookmark removal.
 
         """
-        super(EditraStc, self).RemoveAllBookmarks()
+        self.RemoveAllMarkers(ed_marker.Bookmark())
         mdata = dict(stc=self, added=False, line=-1)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_BOOKMARK, mdata)
 
@@ -328,8 +328,9 @@ class EditraStc(ed_basestc.EditraBaseStc):
         @return: list of line numbers
 
         """
-        return [mark for mark in xrange(self.GetLineCount())
-                if self.MarkerGet(mark)]
+        MarkIsSet = ed_marker.Bookmark.IsSet
+        return [line for line in range(self.GetLineCount())
+                if MarkIsSet(self, line)]
 
     def DoBraceHighlight(self):
         """Perform a brace matching highlight
@@ -884,7 +885,9 @@ class EditraStc(ed_basestc.EditraBaseStc):
         # when the mouse has not dwelled within the buffer area
         mpoint = wx.GetMousePosition()
         brect = self.GetScreenRect()
-        if not brect.Contains(mpoint) or not self.IsShown():
+        if not brect.Contains(mpoint) or \
+           not self.IsShown() or \
+           not self.GetTopLevelParent().IsActive():
             return
 
         position = evt.Position
@@ -958,14 +961,15 @@ class EditraStc(ed_basestc.EditraBaseStc):
         elif margin_num == ed_basestc.MARK_MARGIN:
             # Bookmarks ect...
             line_clicked = self.LineFromPosition(evt.GetPosition())
-            if ed_marker.Bookmark().IsSet(self, line_clicked):
-                self.RemoveBookmark(line_clicked)
-            elif ed_marker.Breakpoint.AnySet(self, line_clicked):
-                # TODO: callback for plugins that set breakpoint?
-                self.DeleteBreakpoint(line_clicked)
-            else:
-                # TODO: add callback to allow plugin to set callback
-                self.AddBookmark(line_clicked)
+            # Hook for client code to interact with margin clicks
+            data = dict(stc=self, line=line_clicked)
+            ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_MARGIN_CLICK, msgdata=data)
+            if not data.get('handled', False):
+                # Default to internal bookmark handling
+                if ed_marker.Bookmark().IsSet(self, line_clicked):
+                    self.RemoveBookmark(line_clicked)
+                else:
+                    self.AddBookmark(line_clicked)
 
     def FoldAll(self):
         """Fold Tree In or Out
@@ -1167,14 +1171,14 @@ class EditraStc(ed_basestc.EditraBaseStc):
 
         """
         mixed = diff = False
-        eol_map = {"\n" : wx.stc.STC_EOL_LF,
-                   "\r\n" : wx.stc.STC_EOL_CRLF,
-                   "\r" : wx.stc.STC_EOL_CR}
+        eol_map = {u"\n" : wx.stc.STC_EOL_LF,
+                   u"\r\n" : wx.stc.STC_EOL_CRLF,
+                   u"\r" : wx.stc.STC_EOL_CR}
 
-        eol = chr(self.GetCharAt(self.GetLineEndPosition(0)))
-        if eol == "\r":
-            tmp = chr(self.GetCharAt(self.GetLineEndPosition(0) + 1))
-            if tmp == "\n":
+        eol = unichr(self.GetCharAt(self.GetLineEndPosition(0)))
+        if eol == u"\r":
+            tmp = unichr(self.GetCharAt(self.GetLineEndPosition(0) + 1))
+            if tmp == u"\n":
                 eol += tmp
 
         # Is the eol used in the document the same as what is currently set.
@@ -1182,12 +1186,14 @@ class EditraStc(ed_basestc.EditraBaseStc):
             diff = True
 
         # Check the lines to see if they are all matching or not.
+        LEPFunct = self.GetLineEndPosition
+        GCAFunct = self.GetCharAt
         for line in range(self.GetLineCount() - 1):
-            end = self.GetLineEndPosition(line)
-            tmp = chr(self.GetCharAt(end))
-            if tmp == "\r":
-                tmp2 = chr(self.GetCharAt(self.GetLineEndPosition(0) + 1))
-                if tmp2 == "\n":
+            end = LEPFunct(line)
+            tmp = unichr(GCAFunct(end))
+            if tmp == u"\r":
+                tmp2 = unichr(GCAFunct(LEPFunct(0) + 1))
+                if tmp2 == u"\n":
                     tmp += tmp2
             if tmp != eol:
                 mixed = True
