@@ -9,8 +9,8 @@
 """Unittest cases for testing the StyleManager"""
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testStyleMgr.py 65165 2010-08-02 22:04:37Z CJP $"
-__revision__ = "$Revision: 65165 $"
+__svnid__ = "$Id: testStyleMgr.py 66518 2011-01-02 04:36:30Z CJP $"
+__revision__ = "$Revision: 66518 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -188,11 +188,27 @@ class StyleMgrTest(unittest.TestCase):
 
     def testParseStyleData(self):
         """Test parsing Editra Style Sheets"""
+        # Test valid style sheet
         data = common.GetFileContents(self.stylesheet)
         styledict = self.mgr.ParseStyleData(data)
         for tag, item in styledict.iteritems():
             self.assertTrue(isinstance(tag, types.UnicodeType), "%s Is not Unicode!" % tag)
             self.assertTrue(isinstance(item, ed_style.StyleItem))
+        # Test loading sheet with malformed data
+        sheet_path = common.GetDataFilePath('incorrect_syntax.ess')
+        data = common.GetFileContents(sheet_path)
+        styledict2 = self.mgr.ParseStyleData(data)
+        self.assertTrue(len(styledict) > len(styledict2))
+        for tag, item in styledict2.iteritems():
+            self.assertTrue(isinstance(tag, types.UnicodeType), "%s Is not Unicode!" % tag)
+            self.assertTrue(isinstance(item, ed_style.StyleItem))
+        # Test stylesheet that is all on one line
+        sheet_path = common.GetDataFilePath('one_liner.ess')
+        data = common.GetFileContents(sheet_path)
+        styledict3 = self.mgr.ParseStyleData(data)
+        for tag, item in styledict3.iteritems():
+            self.assertTrue(isinstance(tag, types.UnicodeType), "%s Is not Unicode!" % tag)
+            self.assertTrue(isinstance(item, ed_style.StyleItem))
 
     def testPackStyleSet(self):
         """Test packing an incomplete style set"""
